import { FormProps, FormSchema } from '@/components/Table';

// 3-年度资金计划详情
export const annualFormSchema: FormSchema[] = [
  {
    field: 'year',
    labelWidth: '140px',
    label: '填报周期',
    required: false,
    component: 'Input',
  },
  {
    label: '公司名称',
    field: 'companyName',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '项目名称',
    field: 'projectName',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '项目类型',
    field: 'projectType',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '建设地点',
    field: 'constructionSite',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '计划投资',
    labelWidth: '140px',
    field: 'planFunds',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '立项总投资',
    labelWidth: '140px',
    field: 'totalInvestment',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '上一年资金执行情况计划额',
    labelWidth: '140px',
    field: 'situationPlanLimit',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '上一年资金执行情况实付额',
    labelWidth: '140px',
    field: 'actualAmountSituation',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '上一年累计实付额度',
    labelWidth: '140px',
    field: 'cumulativeActualLimit',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '年资金计划额合计',
    labelWidth: '140px',
    field: 'plannedQuotaTotal',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '专项拨款合计',
    labelWidth: '140px',
    field: 'specialFundTotal',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '银行融资合计',
    labelWidth: '140px',
    field: 'bankFinancingTotal',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '自有资金合计',
    labelWidth: '140px',
    field: 'ownFundsTotal',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '当年资金缺口',
    labelWidth: '140px',
    field: 'fundingGap',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '建设性质',
    labelWidth: '140px',
    field: 'attribute',
    required: false,
    component: 'Select',
    componentProps: {
      options: [
        { label: '新建', value: '0' },
        { label: '结转', value: '1' },
        { label: '缓建', value: '2' },
      ],
      disabled: true,
      style: { border: 'none' },
    },
  },
  {
    field: 'time',
    component: 'RangePicker',
    label: '开竣工时间',
    required: false,
    icon: 'healthicons:i-schedule-school-date-time-outline',
    colProps: { span: 7, offset: 1 },
    componentProps: {
      placeholder: ['开始日期', '结束日期'],
      style: { width: '100%' },
      valueFormat: 'YYYY-MM-DD',
      format: 'YYYY-MM-DD',
    },
    colProps: {
      offset: 2,
    },
  },
  {
    label: '当年底预计形象进度',
    labelWidth: '140px',
    field: 'schedule',
    required: false,
    component: 'Select',
    componentProps: {
      options: [
        {
          label: 'A(已经立项实施的跨年工程)',
          value: '0',
        },
        {
          label: 'B(该年度必须建设的项目)',
          value: '1',
        },
        {
          label: 'C(可缓建项目)',
          value: '2',
        },
      ],
    },
  },
  {
    label: '项目主管部门',
    labelWidth: '140px',
    field: 'competentDepartment',
    required: false,
    component: 'Input',
  },
  {
    label: '备注',
    labelWidth: '140px',
    field: 'remark',
    required: false,
    component: 'Input',
  },
];

export const exportUrl = '/pro/export/yearEngineer';

//查询条件
export function getFormConfig(): Partial<FormProps> {
  return {
    labelWidth: 100,
    schemas: [
      {
        field: 'year',
        label: '填报周期',
        component: 'DatePicker',
        componentProps: {
          placeholder: '选择填报周期',
          picker: 'year',
          valueFormat: 'YYYY',
          format: 'YYYY',
          style: {
            width: '100%',
          },
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '公司名称',
        field: 'companyName',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '项目名称',
        field: 'projectName',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '建设地点',
        field: 'constructionSite',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '立项总投资',
        field: 'totalInvestment',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '年资金计划额合计',
        field: 'plannedQuotaTotal',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '专项拨款合计',
        field: 'specialFundTotal',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '银行融资合计',
        field: 'bankFinancingTotal',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '自有资金合计',
        field: 'ownFundsTotal',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '当年资金缺口',
        field: 'fundingGap',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '建设性质',
        field: 'attribute',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            { label: '新建', value: '0' },
            { label: '结转', value: '1' },
            { label: '缓建', value: '2' },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '开工时间',
        field: 'beginTime',
        labelWidth: '140px',
        component: 'DatePicker',
        componentProps: {
          picker: 'date',
          valueFormat: 'YYYY-MM-DD',
          format: 'YYYY-MM-DD',
          style: {
            width: '100%',
          },
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '竣工时间',
        field: 'endTime',
        labelWidth: '140px',
        component: 'DatePicker',
        componentProps: {
          picker: 'date',
          valueFormat: 'YYYY-MM-DD',
          format: 'YYYY-MM-DD',
          style: {
            width: '100%',
          },
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '当年底预计形象进度',
        field: 'schedule',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: 'A(已经立项实施的跨年工程)',
              value: '0',
            },
            {
              label: 'B(该年度必须建设的项目)',
              value: '1',
            },
            {
              label: 'C(可缓建项目)',
              value: '2',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '项目主管部门',
        field: 'competentDepartment',
        labelWidth: '140px',
        component: 'InputNumber',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '备注',
        field: 'remark',
        labelWidth: '140px',
        component: 'InputNumber',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
    ],
  };
}
