import { FormProps, FormSchema } from '@/components/Table';

// 7-招标管理详情
export const biddingManagementFormSchema: FormSchema[] = [
  {
    field: 'tenderYear',
    labelWidth: '140px',
    label: '填报年份',
    required: false,
    component: 'Input',
  },
  {
    label: '项目名称',
    field: 'projectName',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '立项投资额',
    field: 'investmentAmount',
    labelWidth: '140px',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '资金来源',
    field: 'fundingSource',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '招标类型',
    labelWidth: '140px',
    field: 'biddingType',
    required: false,
    component: 'Input',
  },
  {
    label: '评标方法',
    labelWidth: '140px',
    field: 'evaluationMethod',
    required: false,
    component: 'Input',
  },
  {
    label: '招标内容',
    labelWidth: '140px',
    field: 'tenderContent',
    required: false,
    component: 'Input',
  },
  {
    label: '招标控制',
    labelWidth: '140px',
    field: 'controlPrice',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '建设模式',
    labelWidth: '140px',
    field: 'constructionMode',
    required: false,
    component: 'Input',
  },
  {
    label: '招标采购方式',
    labelWidth: '140px',
    field: 'procurementMethod',
    required: false,
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '建委招标',
          value: '建委招标',
        },
        {
          label: '平台招标',
          value: '平台招标',
        },
        {
          label: '邀标比选',
          value: '邀标比选',
        },
        {
          label: '直接委托',
          value: '直接委托',
        },
        {
          label: '评分定离',
          value: '评分定离',
        },
      ],
    },
  },
  {
    label: '招标完成情况',
    labelWidth: '140px',
    field: 'completionStatus',
    required: false,
    component: 'Input',
  },
  {
    label: '开标时间',
    labelWidth: '140px',
    field: 'openingTime',
    required: false,
    component: 'Input',
  },
  {
    label: '中标单位',
    labelWidth: '140px',
    field: 'winningBidder',
    required: false,
    component: 'Input',
  },
  {
    label: '中标金额',
    labelWidth: '140px',
    field: 'winningAmount',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '中标工期',
    labelWidth: '140px',
    field: 'winningPeriod',
    required: false,
    component: 'Input',
  },
  {
    label: '合同签订日期',
    labelWidth: '140px',
    field: 'signingDate',
    required: false,
    component: 'Input',
  },
  {
    label: '会议纪要',
    labelWidth: '140px',
    field: 'meetingMinute',
    required: false,
    component: 'Input',
  },
  {
    label: '招标信息发布渠道',
    labelWidth: '140px',
    field: 'releaseChannels',
    required: false,
    component: 'Input',
  },
  {
    label: '详细信息',
    labelWidth: '140px',
    field: 'detailedInformation',
    required: false,
    component: 'Input',
  },
  {
    label: '招标公告发布网址\n' + '\n' + '（仅限公开招标项目）',
    labelWidth: '140px',
    field: 'publishWebsite',
    required: false,
    component: 'Input',
  },
  {
    label: '中标结果公示网址\n' + '\n' + '（仅限公开招标项目）',
    labelWidth: '140px',
    field: 'publicityWebsite',
    required: false,
    component: 'Input',
  },
  {
    label: '是否存在投诉举报情况',
    labelWidth: '140px',
    field: 'isReportingSituation',
    required: false,
    component: 'Input',
  },
  {
    label: '投诉举报解决处理情况',
    labelWidth: '140px',
    field: 'handSituation',
    required: false,
    component: 'Input',
  },
  {
    label: '备注',
    labelWidth: '140px',
    field: 'remark',
    required: false,
    component: 'Input',
  },
];

//招标管理-查询条件
export function getFormConfig(): Partial<FormProps> {
  return {
    labelWidth: 100,
    schemas: [
      {
        field: 'tenderYear',
        label: '填报年份',
        component: 'DatePicker',
        componentProps: {
          placeholder: '选择填报年份',
          picker: 'year',
          valueFormat: 'YYYY',
          format: 'YYYY',
          style: {
            width: '100%',
          },
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '填报季度',
        field: 'biddingQuarter',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '第一季度',
              value: '第一季度',
              key: '第一季度',
            },
            {
              label: '第二季度',
              value: '第二季度',
              key: '第二季度',
            },
            {
              label: '第三季度',
              value: '第三季度',
              key: '第三季度',
            },
            {
              label: '第四季度',
              value: '第四季度',
              key: '第四季度',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '项目名称',
        field: 'projectName',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '立项投资额',
        field: 'investmentAmount',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '资金来源',
        field: 'fundingSource',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '自筹',
              value: '自筹',
              key: '自筹',
            },
            {
              label: '财政资金',
              value: '财政资金',
              key: '财政资金',
            },
            {
              label: '专项债',
              value: '专项债',
              key: '专项债',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '招标类型',
        field: 'biddingType',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '施工',
              value: '施工',
            },
            {
              label: '监理',
              value: '监理',
            },
            {
              label: '设计',
              value: '设计',
            },
            {
              label: '图审',
              value: '图审',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '招标内容',
        field: 'tenderContent',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '招标控制',
        field: 'controlPrice',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '建设模式',
        field: 'constructionMode',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '全部项目',
              value: undefined,
            },
            {
              label: '自建',
              value: '自建',
            },
            {
              label: '委托建设',
              value: '委托建设',
            },
            {
              label: '代建',
              value: '代建',
            },
            {
              label: '承建',
              value: '承建',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '招标采购方式',
        field: 'procurementMethod',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '建委招标',
              value: '建委招标',
            },
            {
              label: '平台招标',
              value: '平台招标',
            },
            {
              label: '邀标比选',
              value: '邀标比选',
            },
            {
              label: '直接委托',
              value: '直接委托',
            },
            {
              label: '评分定离',
              value: '评分定离',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '招标完成情况',
        field: 'completionStatus',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '开标时间',
        field: 'openingTime',
        labelWidth: '140px',
        component: 'DatePicker',
        componentProps: {
          picker: 'month',
          valueFormat: 'YYYY-MM',
          format: 'YYYY-MM',
          style: {
            width: '100%',
          },
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '中标单位',
        field: 'winningBidder',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '中标金额',
        field: 'winningAmount',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '中标工期',
        field: 'winningPeriod',
        labelWidth: '140px',
        component: 'Input',
      },
      {
        label: '合同签订日期',
        field: 'signingDate',
        labelWidth: '140px',
        component: 'DatePicker',
        componentProps: {
          picker: 'date',
          valueFormat: 'YYYY-MM-DD',
          format: 'YYYY-MM-DD',
          style: {
            width: '100%',
          },
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '会议纪要',
        field: 'meetingMinute',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '招标信息发布渠道',
        field: 'releaseChannels',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '中国招标投标公共服务平台',
              value: '中国招标投标公共服务平台',
            },
            {
              label: '公司OA和公众号',
              value: '公司OA和公众号',
            },
            {
              label: '天津市公共资源交易中心',
              value: '天津市公共资源交易中心',
            },
            {
              label: '邮箱',
              value: '邮箱',
            },
            {
              label: '其他',
              value: '其他',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '招标公告发布网址（仅限公开招标项目）',
        field: 'publishWebsite',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '中标结果公示网址（仅限公开招标项目）',
        field: 'publicityWebsite',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '是否存在投诉举报情况',
        field: 'isReportingSituation',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '是',
              value: '是',
              key: '是',
            },
            {
              label: '否',
              value: '否',
              key: '否',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '投诉举报解决处理情况',
        field: 'handSituation',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '备注',
        field: 'remark',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
    ],
  };
}
