import { FormProps, FormSchema } from '@/components/Table';

// 6-招标计划详情
export const biddingFormSchema: FormSchema[] = [
  {
    field: 'tenderYear',
    labelWidth: '140px',
    label: '填报年份',
    required: false,
    component: 'Input',
  },
  {
    label: '项目名称',
    field: 'projectName',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '立项主体',
    field: 'projectInitiator',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '资金来源',
    field: 'fundingSource',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '立项投资额',
    labelWidth: '140px',
    field: 'investmentAmount',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '招标类型',
    labelWidth: '140px',
    field: 'biddingType',
    required: false,
    component: 'Input',
  },
  {
    label: '招标内容',
    labelWidth: '140px',
    field: 'tenderContent',
    required: false,
    component: 'Input',
  },
  {
    label: '预计控制价',
    labelWidth: '140px',
    field: 'controlPrice',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '计划工期',
    labelWidth: '140px',
    field: 'plannedPeriod',
    required: false,
    component: 'Input',
  },
  {
    label: '招标方式',
    labelWidth: '140px',
    field: 'biddingMethod',
    required: false,
    component: 'Input',
  },
  {
    label: '计划招标周期',
    labelWidth: '140px',
    field: 'biddingPeriod',
    required: false,
    component: 'Input',
  },
  {
    label: '备注',
    labelWidth: '140px',
    field: 'remark',
    required: false,
    component: 'Input',
  },
];

//招标计划-查询条件
export function getFormConfig(): Partial<FormProps> {
  return {
    labelWidth: 100,
    schemas: [
      {
        field: 'tenderYear',
        label: '填报年份',
        component: 'DatePicker',
        componentProps: {
          placeholder: '选择填报年份',
          picker: 'year',
          valueFormat: 'YYYY',
          format: 'YYYY',
          style: {
            width: '100%',
          },
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '填报季度',
        field: 'biddingQuarter',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '第一季度',
              value: '第一季度',
              key: '第一季度',
            },
            {
              label: '第二季度',
              value: '第二季度',
              key: '第二季度',
            },
            {
              label: '第三季度',
              value: '第三季度',
              key: '第三季度',
            },
            {
              label: '第四季度',
              value: '第四季度',
              key: '第四季度',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '项目名称',
        field: 'projectName',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '立项主体',
        field: 'projectInitiator',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '资金来源',
        field: 'fundingSource',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '自筹',
              value: '自筹',
              key: '自筹',
            },
            {
              label: '财政资金',
              value: '财政资金',
              key: '财政资金',
            },
            {
              label: '专项债',
              value: '专项债',
              key: '专项债',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '立项投资额',
        field: 'investmentAmount',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '招标类型',
        field: 'biddingType',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '施工',
              value: '施工',
            },
            {
              label: '监理',
              value: '监理',
            },
            {
              label: '设计',
              value: '设计',
            },
            {
              label: '图审',
              value: '图审',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '招标内容',
        field: 'tenderContent',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '预计控制价',
        field: 'controlPrice',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '招标方式',
        field: 'biddingMethod',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '建委招标',
              value: '建委招标',
            },
            {
              label: '平台招标',
              value: '平台招标',
            },
            {
              label: '邀标比选',
              value: '邀标比选',
            },
            {
              label: '直接委托',
              value: '直接委托',
            },
            {
              label: '评分定离',
              value: '评分定离',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '备注',
        field: 'remark',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
    ],
  };
}
