import { FormProps, FormSchema } from '@/components/Table';

// 5-已竣工详情
export const completedFormSchema: FormSchema[] = [
  {
    field: 'filingCycle',
    labelWidth: '140px',
    label: '填报周期',
    required: false,
    component: 'Input',
  },
  {
    label: '公司名称',
    field: 'company',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '项目名称',
    field: 'projectName',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '项目类型',
    field: 'projectType',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '建设地点',
    field: 'constructionSite',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '合同额',
    field: 'contractAmount',
    labelWidth: '140px',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '结算金额',
    field: 'completionSettlement',
    labelWidth: '140px',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '立项总投资合计',
    labelWidth: '140px',
    field: 'projectApproval',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '上一年底前累计实付额',
    labelWidth: '140px',
    field: 'totalActualPay',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '年资金计划额合计',
    labelWidth: '140px',
    field: 'totalValue',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '专项拨款合计',
    labelWidth: '140px',
    field: 'totalSpecialBond',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '银行融资合计',
    labelWidth: '140px',
    field: 'totalBankFinancing',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '自有资金合计',
    labelWidth: '140px',
    field: 'totalOwnFunds',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '当年资金缺口',
    labelWidth: '140px',
    field: 'fundingGap',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '资金执行情况-计划额',
    labelWidth: '140px',
    field: 'annualFund',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '资金执行情况-实付额',
    labelWidth: '140px',
    field: 'actualPay',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '项目主管部门',
    labelWidth: '140px',
    field: 'competentDepartment',
    required: false,
    component: 'Input',
  },
  {
    label: '备注',
    labelWidth: '140px',
    field: 'remarks',
    required: false,
    component: 'Input',
  },
];

export const exportUrl = '/pro/export/overdueFunds';

//查询条件
export function getFormConfig(): Partial<FormProps> {
  return {
    labelWidth: 100,
    schemas: [
      {
        field: 'filingCycle',
        label: '填报周期',
        component: 'DatePicker',
        componentProps: {
          placeholder: '选择填报周期',
          picker: 'year',
          valueFormat: 'YYYY',
          format: 'YYYY',
          style: {
            width: '100%',
          },
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '公司名称',
        field: 'company',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '项目名称',
        field: 'projectName',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '建设地点',
        field: 'constructionSite',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '立项总投资合计',
        field: 'projectApproval',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '上一年底前累计实付额',
        field: 'totalActualPay',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '年资金计划额合计',
        field: 'totalValue',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '专项拨款合计',
        field: 'totalSpecialBond',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '银行融资合计',
        field: 'totalBankFinancing',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '自有资金合计',
        field: 'totalOwnFunds',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '当年资金缺口',
        field: 'fundingGap',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '项目主管部门',
        field: 'competentDepartment',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '备注',
        field: 'remarks',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
    ],
  };
}
