import { FormProps, FormSchema } from '@/components/Table';

// 1-投资计划详情
export const columnsFormSchema: FormSchema[] = [
  {
    field: 'filingCycle',
    labelWidth: '140px',
    label: '填报年份',
    required: false,
    component: 'Input',
  },
  {
    label: '项目名称',
    field: 'projectName',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '建设地点',
    field: 'constructionSite',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '项目概况',
    field: 'projectOverview',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '建设规模',
    labelWidth: '140px',
    field: 'constructionScale',
    required: false,
    component: 'Input',
  },
  {
    label: '建设目的及项目功能',
    labelWidth: '140px',
    field: 'constructionPurpose',
    required: false,
    component: 'Input',
  },
  {
    label: '建设模式',
    labelWidth: '140px',
    field: 'constructionMode',
    required: false,
    component: 'Input',
  },
  {
    label: '资金来源',
    labelWidth: '140px',
    field: 'fundingSource',
    required: false,
    component: 'Input',
  },
  {
    label: '项目类型',
    labelWidth: '140px',
    field: 'projectType',
    required: false,
    component: 'Input',
  },
  {
    label: '总投资',
    labelWidth: '140px',
    field: 'totalInvestment',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '三年滚动投资计划',
    labelWidth: '140px',
    field: 'totalAmount',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '该年财政预算匹配资金',
    labelWidth: '140px',
    field: 'matchingFunds',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '其中专项债项目该年预计使用专项债资金',
    labelWidth: '140px',
    field: 'specialBondFunds',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '该年计划资金',
    labelWidth: '140px',
    field: 'planFunds',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '建设性质',
    labelWidth: '140px',
    field: 'attribute',
    required: false,
    component: 'Select',
    componentProps: {
      options: [
        { label: '新建', value: '0' },
        { label: '结转', value: '1' },
        { label: '缓建', value: '2' },
      ],
      disabled: true,
      style: { border: 'none' },
    },
  },
  {
    field: 'time',
    component: 'RangePicker',
    label: '开竣工时间',
    required: false,
    icon: 'healthicons:i-schedule-school-date-time-outline',
    colProps: { span: 7, offset: 1 },
    componentProps: {
      placeholder: ['开始日期', '结束日期'],
      style: { width: '100%' },
      valueFormat: 'YYYY-MM-DD',
      format: 'YYYY-MM-DD',
    },
    colProps: {
      offset: 2,
    },
  },

  {
    label: '该年底形象进度',
    field: 'schedule',
    labelWidth: '140px',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: 'A(已经立项实施的跨年工程)',
          value: '0',
        },
        {
          label: 'B(该年度必须建设的项目)',
          value: '1',
        },
        {
          label: 'C(可缓建项目)',
          value: '2',
        },
      ],
    },
  },
  {
    label: '实施主体',
    labelWidth: '140px',
    field: 'implementingEntity',
    required: false,
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '了解产品',
          value: '了解产品',
          key: '了解产品',
        },
        {
          label: '正在跟进',
          value: '正在跟进',
          key: '正在跟进',
        },
        {
          label: '正在试用',
          value: '正在试用',
          key: '正在试用',
        },
        {
          label: '准备购买',
          value: '准备购买',
          key: '准备购买',
        },
        {
          label: '准备付款',
          value: '准备付款',
          key: '准备付款',
        },
        {
          label: '已经购买',
          value: '已经购买',
          key: '已经购买',
        },
        {
          label: '暂时闲置',
          value: '暂时闲置',
          key: '暂时闲置',
        },
      ],
    },
  },
  {
    label: '项目主管部门',
    labelWidth: '140px',
    field: 'competentDepartment',
    required: false,
    component: 'Input',
  },
  {
    label: '备注',
    labelWidth: '140px',
    field: 'remarks',
    required: false,
    component: 'Input',
  },
];

export const exportUrl = '/pro/export/investmentPlan';

//查询条件
export function getFormConfig(): Partial<FormProps> {
  return {
    labelWidth: 100,
    schemas: [
      {
        field: 'filingCycle',
        label: '填报年份',
        component: 'DatePicker',
        componentProps: {
          placeholder: '选择填报年份',
          picker: 'year',
          valueFormat: 'YYYY',
          format: 'YYYY',
          style: {
            width: '100%',
          },
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '项目名称',
        field: 'projectName',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '建设地点',
        field: 'constructionSite',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '项目概况',
        field: 'projectOverview',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '建设规模',
        field: 'constructionScale',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '建设目的及项目功能',
        field: 'constructionPurpose',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '建设模式',
        field: 'constructionMode',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '全部项目',
              value: undefined,
            },
            {
              label: '自建',
              value: '自建',
            },
            {
              label: '委托建设',
              value: '委托建设',
            },
            {
              label: '代建',
              value: '代建',
            },
            {
              label: '承建',
              value: '承建',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '资金来源',
        field: 'fundingSource',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '自筹',
              value: '自筹',
              key: '自筹',
            },
            {
              label: '财政资金',
              value: '财政资金',
              key: '财政资金',
            },
            {
              label: '专项债',
              value: '专项债',
              key: '专项债',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '项目类型',
        field: 'projectType',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '公共设施配套类',
              value: '公共设施配套类',
              key: '公共设施配套类',
            },
            {
              label: '基础设施类',
              value: '基础设施类',
              key: '基础设施类',
            },
            {
              label: '产业载体类',
              value: '产业载体类',
              key: '产业载体类',
            },
            {
              label: '房地产类',
              value: '房地产类',
              key: '房地产类',
            },
            {
              label: '存量盘活类',
              value: '存量盘活类',
              key: '存量盘活类',
            },
            {
              label: '其他类（零星工程)',
              value: '其他类（零星工程)',
              key: '其他类（零星工程)',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '总投资',
        field: 'totalInvestment',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '三年滚动投资计划',
        field: 'totalAmount',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '该年财政预算匹配资金',
        field: 'specialBondFunds',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '其中专项债项目该年预计使用专项债资金',
        field: 'specialBondFunds',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '该年计划资金',
        field: 'planFunds',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '建设性质',
        field: 'attribute',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            { label: '新建', value: '0' },
            { label: '结转', value: '1' },
            { label: '缓建', value: '2' },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '开工时间',
        field: 'beginTime',
        labelWidth: '140px',
        component: 'DatePicker',
        componentProps: {
          picker: 'date',
          valueFormat: 'YYYY-MM-DD',
          format: 'YYYY-MM-DD',
          style: {
            width: '100%',
          },
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '竣工时间',
        field: 'endTime',
        labelWidth: '140px',
        component: 'DatePicker',
        componentProps: {
          picker: 'date',
          valueFormat: 'YYYY-MM-DD',
          format: 'YYYY-MM-DD',
          style: {
            width: '100%',
          },
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '该年底形象进度',
        field: 'schedule',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: 'A(已经立项实施的跨年工程)',
              value: '0',
            },
            {
              label: 'B(该年度必须建设的项目)',
              value: '1',
            },
            {
              label: 'C(可缓建项目)',
              value: '2',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '实施主体',
        field: 'implementingEntity',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '了解产品',
              value: '了解产品',
              key: '了解产品',
            },
            {
              label: '正在跟进',
              value: '正在跟进',
              key: '正在跟进',
            },
            {
              label: '正在试用',
              value: '正在试用',
              key: '正在试用',
            },
            {
              label: '准备购买',
              value: '准备购买',
              key: '准备购买',
            },
            {
              label: '准备付款',
              value: '准备付款',
              key: '准备付款',
            },
            {
              label: '已经购买',
              value: '已经购买',
              key: '已经购买',
            },
            {
              label: '暂时闲置',
              value: '暂时闲置',
              key: '暂时闲置',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '项目主管部门',
        field: 'competentDepartment',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '备注',
        field: 'completionRemarks',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
    ],
  };
}
