import { FormProps, FormSchema } from '@/components/Table';

// 4-查看月度资金计划详情
export const monthFormSchema: FormSchema[] = [
  {
    field: 'monthYear',
    labelWidth: '140px',
    label: '填报年份',
    required: false,
    component: 'Input',
  },
  {
    label: '公司名称',
    field: 'companyName',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '项目名称',
    field: 'projectName',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '收款单位',
    field: 'collectingUnit',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '结算金额',
    field: 'investmentAmount',
    labelWidth: '140px',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '合同名称',
    field: 'contrcatName',
    labelWidth: '140px',
    required: false,
    component: 'Input',
  },
  {
    label: '合同额',
    labelWidth: '140px',
    field: 'contractAmount',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '上月实际完成值',
    labelWidth: '140px',
    field: 'completionValueActual',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '累计完成值',
    labelWidth: '140px',
    field: 'accumulateCompletionValue',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '本月计划完成值',
    labelWidth: '140px',
    field: 'planCompletionValue',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '上月计划数',
    labelWidth: '140px',
    field: 'lastMonthPlan',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '上月实付数',
    labelWidth: '140px',
    field: 'lastMonthActual',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '累计支付数',
    labelWidth: '140px',
    field: 'accumulatePayment',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '本月计划数',
    labelWidth: '140px',
    field: 'thisPlanNumber',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '专项债拨款',
    labelWidth: '140px',
    field: 'specialFund',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '政府拨款',
    labelWidth: '140px',
    field: 'governmentFund',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '银行融资',
    labelWidth: '140px',
    field: 'banFinancing',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '自有资金',
    labelWidth: '140px',
    field: 'ownFund',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '资金来源类型',
    labelWidth: '140px',
    field: 'sourceType',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '资金缺口',
    labelWidth: '140px',
    field: 'fundGap',
    required: false,
    component: 'Input',
    componentProps: {
      addonAfter: '万元',
    },
  },
  {
    label: '支付等级',
    labelWidth: '140px',
    field: 'paymentLevel',
    required: false,
    component: 'Input',
  },
  {
    label: '备注',
    labelWidth: '140px',
    field: 'remark',
    required: false,
    component: 'Input',
  },
];

//月季度-查询条件
export function getFormConfig(): Partial<FormProps> {
  return {
    labelWidth: 100,
    schemas: [
      {
        field: 'monthYear',
        label: '填报年份',
        component: 'DatePicker',
        componentProps: {
          picker: 'month',
          valueFormat: 'YYYY-MM',
          format: 'YYYY-MM',
          style: {
            width: '100%',
          },
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '公司名称',
        field: 'companyName',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '项目名称',
        field: 'projectName',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '收款单位',
        field: 'collectingUnit',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '合同额',
        field: 'contractAmount',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '上月实际完成值',
        field: 'completionValueActual',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '累计完成值',
        field: 'accumulateCompletionValue',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '本月计划完成值',
        field: 'planCompletionValue',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '上月计划数',
        field: 'lastMonthPlan',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '上月实付数',
        field: 'lastMonthActual',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '累计支付数',
        field: 'accumulatePayment',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '本月计划数',
        field: 'thisPlanNumber',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '专项债拨款',
        field: 'specialFund',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '政府拨款',
        field: 'governmentFund',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '银行融资',
        field: 'banFinancing',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '自有资金',
        field: 'ownFund',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '资金缺口',
        field: 'fundGap',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '支付等级',
        field: 'paymentLevel',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            { label: 'A（必须支付）', value: 'A（必须支付）' },
            { label: 'B（可暂缓支付但有维稳风险）', value: 'B（可暂缓支付但有维稳风险）' },
            { label: 'C（随财政拨款支付，无维稳风险）', value: 'C（随财政拨款支付，无维稳风险）' },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '备注',
        field: 'remark',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
    ],
  };
}
