import { FormSchema, BasicColumn } from '@/components/Table';
import { uploadApi } from '@/api/sys/upload';
import { useUserStore } from '@/store/modules/user';

const deptId = useUserStore().userInfo.deptParentId;
export let formSchema: FormSchema[] = [
  // {
  //   field: 'logo',
  //   label: '项目logo',
  //   labelWidth: '140px',
  //   component: 'ImageUpload',
  //   componentProps: {
  //     api: uploadApi,
  //     resultField: 'data.data.fullPath',
  //     accept: ['png', 'jpeg', 'jpg'],
  //     multiple: false,
  //     name: 'multipartFile',
  //   },
  // },
  {
    field: 'projectName',
    labelWidth: '140px',
    label: '项目名称',
    required: true,
    component: 'Input',
  },
  {
    labelWidth: '140px',
    field: 'commencementTime',
    label: '开工时间',
    component: 'DatePicker',
    required: true,
    componentProps: {
      picker: 'month',
      valueFormat: 'YYYY-MM',
      format: 'YYYY-MM',
      style: { width: '100%' },
    },
  },
  {
    labelWidth: '140px',
    field: 'timeForCompletion',
    label: '竣工时间',
    component: 'DatePicker',
    componentProps: {
      picker: 'month',
      valueFormat: 'YYYY-MM',
      format: 'YYYY-MM',
      style: { width: '100%' },
    },
  },
  {
    field: 'projectInvestment',
    label: '立项总投资',
    component: 'InputNumber',
    componentProps: {
      addonAfter: '万元',
    },
    labelWidth: '140px',
  },
  {
    field: 'isReserveProject',
    label: '储备项目',
    component: 'RadioButtonGroup',
    defaultValue: 'false',
    componentProps: {
      options: [
        { label: '是', value: 'true' },
        { label: '否', value: 'false' },
      ],
    },
    labelWidth: '140px',
  },
  {
    label: '建设地点',
    field: 'constructionSite',
    labelWidth: '140px',
    required: true,
    component: 'Select',
    componentProps: {
      options: [
        { label: '华苑片区', value: '华苑片区' },
        { label: '渤龙湖片区', value: '渤龙湖片区' },
        { label: '海洋片区', value: '海洋片区' },
        { label: '北塘片区', value: '北塘片区' },
        { label: '其他', value: '其他' },
      ],
    },
  },
  {
    label: '建设模式',
    labelWidth: '140px',
    field: 'constructionMode',
    required: true,
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '委托建设',
          value: '委托建设',
        },
        {
          label: '承建',
          value: '承建',
        },
        {
          label: '代建',
          value: '代建',
        },
        {
          label: '自建',
          value: '自建',
        },
      ],
    },
  },
  {
    label: '项目类型',
    labelWidth: '140px',
    field: 'projectType',
    required: true,
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '公共设施配套类',
          value: '公共设施配套类',
          key: '公共设施配套类',
        },
        {
          label: '基础设施类',
          value: '基础设施类',
          key: '基础设施类',
        },
        {
          label: '产业载体类',
          value: '产业载体类',
          key: '产业载体类',
        },
        {
          label: '房地产类',
          value: '房地产类',
          key: '房地产类',
        },
        {
          label: '存量盘活类',
          value: '存量盘活类',
          key: '存量盘活类',
        },
        {
          label: '其他类（零星工程)',
          value: '其他类（零星工程)',
          key: '其他类（零星工程)',
        },
        {
          label: '其他养管类',
          value: '其他养管类',
          key: '其他养管类',
        },
      ],
    },
  },
  {
    label: '建设规模',
    labelWidth: '140px',
    field: 'constructionScale',
    required: true,
    component: 'Input',
  },
  {
    label: '项目概况',
    field: 'projectOverview',
    labelWidth: '140px',
    required: true,
    component: 'InputTextArea',
    componentProps: {
      maxlength: 200,
      showCount: true,
    },
  },
  {
    label: '建设目的及项目功能',
    labelWidth: '140px',
    field: 'constructionPurpose',
    required: true,
    component: 'InputTextArea',
    componentProps: {
      maxlength: 100,
      showCount: true,
    },
  },
  {
    field: 'fundingSource',
    label: '资金来源',
    labelWidth: '140px',
    required: true,
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '政府投资项目（不含专项债）',
          value: '政府投资项目（不含专项债）',
          key: '政府投资项目（不含专项债）',
        },
        {
          label: '公司投资项目（不含专项债）',
          value: '公司投资项目（不含专项债）',
          key: '公司投资项目（不含专项债）',
        },
        {
          label: '专项债项目',
          value: '专项债项目',
          key: '专项债项目',
        },
      ],
    },
  },
  {
    field: 'implementingEntity',
    label: '实施主体',
    required: true,
    labelWidth: '140px',
    component: 'Input',
    componentProps: {
      maxlength: 100,
      showCount: true,
    },
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    field: 'projecName',
    label: '',
    component: 'Input',
    componentProps: {
      placeholder: '输入搜索关键词',
    },
    colProps: { span: 4 },
  },

  {
    field: 'isReserveProject',
    component: 'Select',
    colProps: {
      span: 4,
    },
    componentProps: {
      placeholder: '请选择储备类型',
      options: [
        { label: '储备项目', value: 'true' },
        { label: '非储备项目', value: 'false' },
      ],
    },
  },
  {
    field: 'constructionMode',
    component: 'Select',
    colProps: {
      span: 4,
    },
    componentProps: {
      placeholder: '请选择建设模式',
      options: [
        {
          label: '自建',
          value: '自建',
        },
        {
          label: '委托建设',
          value: '委托建设',
        },
        {
          label: '代建',
          value: '代建',
        },
        {
          label: '承建',
          value: '承建',
        },
      ],
    },
  },
  {
    field: 'departmentId',
    label: '',
    component: 'Select',
    componentProps: {
      placeholder: '选择上报单位',
      options: [],
    },
    ifShow: deptId == '100',
    colProps: { span: 3 },
  },
  {
    field: 'projectType',
    label: '',
    component: 'Select',
    componentProps: {
      placeholder: '项目类型',
      options: [
        {
          label: '公共设施配套类',
          value: '公共设施配套类',
          key: '公共设施配套类',
        },
        {
          label: '基础设施类',
          value: '基础设施类',
          key: '基础设施类',
        },
        {
          label: '产业载体类',
          value: '产业载体类',
          key: '产业载体类',
        },
        {
          label: '房地产类',
          value: '房地产类',
          key: '房地产类',
        },
        {
          label: '存量盘活类',
          value: '存量盘活类',
          key: '存量盘活类',
        },
        {
          label: '其他类（零星工程)',
          value: '其他类（零星工程)',
          key: '其他类（零星工程)',
        },
        {
          label: '其他养管类',
          value: '其他养管类',
          key: '其他养管类',
        },
      ],
    },
    colProps: { span: 3 },
  },
];

export const columns: BasicColumn[] = [
  {
    title: '基本信息',
    dataIndex: 'projectName',
    fixed: 'left',
    width: 250,
    ellipsis: false,
  },
  {
    title: '实施主体',
    dataIndex: 'implementingEntity',
    width: 180,
  },
  {
    title: '建设模式',
    dataIndex: 'constructionMode',
    width: 200,
  },
  {
    title: '建设地点',
    dataIndex: 'constructionSite',
    width: 180,
  },
  {
    title: '项目类型',
    dataIndex: 'projectType',
    width: 180,
  },
  {
    title: '资金来源',
    dataIndex: 'fundingSource',
    width: 180,
  },
  // {
  //   title: '建设目的及项目功能',
  //   dataIndex: 'constructionPurpose',
  //   width: 180,
  // },
  // {
  //   title: '建设规模',
  //   dataIndex: 'constructionScale',
  //   width: 180,
  // },
  {
    title: '上报单位',
    dataIndex: 'departmentName',
    width: 180,
  },
];
export const tabList = [
  {
    key: '1',
    tab: '投资计划',
    component: 'InvestmentPlan',
  },
  {
    key: '2',
    tab: '计划完成情况',
    component: 'performance',
  },
  {
    key: '3',
    tab: '年度资金计划',
    component: 'annualPlan',
  },
  {
    key: '4',
    tab: '月度资金计划',
    component: 'monthlyPlan',
  },
  {
    key: '5',
    tab: '已竣工验收项目陈欠资金计划',
    component: 'completed',
  },
  {
    key: '6',
    tab: '招标计划',
    component: 'biddingPlan',
  },
  {
    key: '7',
    tab: '招标管理',
    component: 'biddingManagement',
  },
  {
    key: '8',
    tab: '结算管理',
    component: 'settlementManagement',
  },
  {
    key: '9',
    tab: '变更签证管理',
    component: 'changeSignature',
  },
  {
    key: '10',
    tab: '安全隐患管理',
    component: 'potentialSafety',
  },
  {
    key: '11',
    tab: '安全教育培训',
    component: 'safetyEducation',
  },
  {
    key: '12',
    tab: '合同管理',
    component: 'contract',
  },
  {
    key: '13',
    tab: '附件记录',
    component: 'annex',
  },
  {
    key: '14',
    tab: '更新记录',
    component: 'updateRecords',
  },
];
