//查询条件
export function getFormConfig(): Partial<FormProps> {
  return {
    labelWidth: 100,
    schemas: [
      {
        field: 'givenYear',
        label: '填报年份',
        component: 'DatePicker',
        componentProps: {
          placeholder: '选择填报周期',
          picker: 'year',
          valueFormat: 'YYYY',
          format: 'YYYY',
          style: {
            width: '100%',
          },
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        field: 'quarter',
        label: '填报季度',
        component: 'Select',
        componentProps: {
          options: [
            { label: '第一季度', value: '第一季度' },
            { label: '第二季度', value: '第二季度' },
            {
              label: '第三季度',
              value: '第三季度',
            },
            {
              label: '第四季度',
              value: '第四季度',
            },
          ],
          placeholder: '季度',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '立项投资额',
        field: 'projectInvestment',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '资金来源',
        field: 'fundingSource',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '招标方式',
        field: 'biddingMethod',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '建委招标',
              value: '1',
            },
            {
              label: '平台招标',
              value: '2',
            },
            {
              label: '邀标比选',
              value: '3',
            },
            {
              label: '直接委托',
              value: '4',
            },
            {
              label: '评分定离',
              value: '5',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '合同类型',
        field: 'contracYpe',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '施工',
              value: '1',
            },
            {
              label: '监理',
              value: '2',
            },
            {
              label: '设计',
              value: '3',
            },
            {
              label: '图审',
              value: '4',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '合同名称',
        field: 'contractName',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '甲方单位名称',
        field: 'firstPartyName',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '乙方单位名称',
        field: 'secondPartyName',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '合同形式',
        field: 'formOfContract',
        labelWidth: '140px',
        component: 'Select',
        componentProps: {
          options: [
            {
              label: '固定总价',
              value: '1',
            },
            {
              label: '固定单价',
              value: '2',
            },
            {
              label: '费率',
              value: '3',
            },
            {
              label: '其他',
              value: '4',
            },
          ],
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '合同签订时间',
        field: 'contractSigningTime',
        labelWidth: '140px',
        component: 'DatePicker',
        componentProps: {
          valueFormat: 'YYYY-MM-DD',
          style: {
            width: '100%',
          },
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '竣工时间',
        field: 'closingTime',
        labelWidth: '140px',
        component: 'DatePicker',
        componentProps: {
          valueFormat: 'YYYY-MM-DD',
          style: {
            width: '100%',
          },
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '结算完成时间',
        field: 'closingTimeDatetime',

        labelWidth: '140px',
        component: 'DatePicker',
        componentProps: {
          valueFormat: 'YYYY-MM-DD',
          style: {
            width: '100%',
          },
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '合同金额',
        field: 'contractAmount',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '签证、变更金额',
        field: 'submittedForSettlement',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '结算报送金额',
        field: 'superContractScale',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '结算审定金额',
        field: 'sumOfMoney',
        labelWidth: '140px',
        component: 'InputNumber',
        componentProps: {
          addonAfter: '万元',
        },
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '结算审核金额超合同额比例',
        field: 'proportionContractAmount',
        labelWidth: '140px',
        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '会议纪要',
        field: 'meetingMinutes',
        labelWidth: '140px',

        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
      {
        label: '备注',
        field: 'remark',
        labelWidth: '140px',

        component: 'Input',
        colProps: {
          xl: 8,
          xxl: 4,
        },
      },
    ],
  };
}

export const exportUrl = '/pro/reportCenter/settlement/export-settlement';
