import { FormSchema, BasicColumn } from '@/components/Table';

export const searchFormSchema: FormSchema[] = [
  {
    field: 'period',
    label: '',
    component: 'DatePicker',
    componentProps: {
      placeholder: '选择填报周期',
      picker: 'year',
      valueFormat: 'YYYY',
      format: 'YYYY',
      style: {
        width: '100%',
      },
    },
    colProps: { span: 5 },
  },
];

// 1-投资计划列表
export const columns: BasicColumn[] = [
  {
    title: '序号',
    dataIndex: 'serialNumber', // 这个dataIndex仅作为标识，不对应实际数据字段
    width: 50, // 可以自定义宽度 // 对应模板中的具名插槽
    scopedSlots: { customRender: 'bodyCell' }, // 对应模板中的具名插槽
  },
  {
    title: '填报年份',
    dataIndex: 'filingCycle',
    width: 200,
  },
  {
    title: '项目名称',
    dataIndex: 'projectName',
    width: 200,
  },
  {
    title: '建设地点',
    dataIndex: 'constructionSite',
    width: 180,
  },
  {
    title: '项目概况',
    dataIndex: 'projectOverview',
    width: 180,
  },
  {
    title: '建设规模',
    dataIndex: 'constructionScale',
    width: 180,
  },
  {
    title: '建设目的及项目功能',
    dataIndex: 'constructionPurpose',
    width: 180,
  },
  {
    title: '建设模式',
    dataIndex: 'constructionMode',
    width: 180,
  },
  {
    title: '资金来源',
    dataIndex: 'fundingSource',
    width: 180,
  },
  {
    title: '项目类型',
    dataIndex: 'projectType',
    width: 180,
  },
  {
    title: '总投资(万元)',
    dataIndex: 'totalInvestment',
    width: 180,
  },
  {
    title: '三年滚动投资计划(万元)',
    dataIndex: 'totalAmount',
    width: 180,
  },
  {
    title: '该年财政预算匹配资金(万元)',
    dataIndex: 'matchingFunds',
    width: 180,
  },
  {
    title: '其中专项债项目该年预计使用专项债资金(万元)',
    dataIndex: 'specialBondFunds',
    width: 180,
  },
  {
    title: '该年计划资金(万元)',
    dataIndex: 'planFunds',
    width: 180,
  },
  {
    title: '建设性质',
    dataIndex: 'attribute',
    width: 180,
  },
  {
    title: '开工竣工时间',
    dataIndex: 'beginTime',
    width: 180,
  },
  {
    title: '该年底形象进度',
    dataIndex: 'schedule',
    width: 180,
  },
  {
    title: '实施主体',
    dataIndex: 'implementingEntity',
    width: 180,
  },
  {
    title: '项目主管部门',
    dataIndex: 'competentDepartment',
    width: 180,
  },
  {
    title: '备注',
    dataIndex: 'remarks',
    width: 180,
  },
];
// 2-计划完成情况列表
export const performanceColumns: BasicColumn[] = [
  {
    title: '序号',
    dataIndex: 'serialNumber', // 这个dataIndex仅作为标识，不对应实际数据字段
    width: 50, // 可以自定义宽度 // 对应模板中的具名插槽
    scopedSlots: { customRender: 'bodyCell' }, // 对应模板中的具名插槽
  },
  {
    title: '填报年份',
    dataIndex: 'filingCycle',
    width: 200,
  },
  {
    title: '项目名称',
    dataIndex: 'projectName',
    width: 200,
  },
  {
    title: '建设地点',
    dataIndex: 'constructionSite',
    width: 180,
  },
  {
    title: '项目概况',
    dataIndex: 'projectOverview',
    width: 180,
  },
  {
    title: '建设规模',
    dataIndex: 'constructionScale',
    width: 180,
  },
  {
    title: '建设目的及项目功能',
    dataIndex: 'constructionPurpose',
    width: 180,
  },
  {
    title: '建设模式',
    dataIndex: 'constructionMode',
    width: 180,
  },
  {
    title: '资金来源',
    dataIndex: 'fundingSource',
    width: 180,
  },
  {
    title: '项目类型',
    dataIndex: 'projectType',
    width: 180,
  },
  {
    title: '总投资(万元)',
    dataIndex: 'totalInvestment',
    width: 180,
  },
  {
    title: '该年计划投资额(万元)',
    dataIndex: 'planNum',
    width: 180,
  },
  {
    title: '该年计划资金(万元)',
    dataIndex: 'planFunds',
    width: 180,
  },
  {
    title: '建设性质',
    dataIndex: 'attribute',
    width: 180,
  },
  {
    title: '开工竣工时间',
    dataIndex: 'beginTime',
    width: 180,
  },
  {
    title: '该年底形象进度',
    dataIndex: 'completionSchedule',
    width: 180,
  },
  {
    title: '实施主体',
    dataIndex: 'implementingEntity',
    width: 180,
  },
  {
    title: '项目主管部门',
    dataIndex: 'competentDepartment',
    width: 180,
  },
  {
    title: '备注',
    dataIndex: 'completionRemarks',
    width: 180,
  },
];
// 3-年度资金计划列表
export const annualPlanColumns: BasicColumn[] = [
  {
    title: '序号',
    dataIndex: 'serialNumber', // 这个dataIndex仅作为标识，不对应实际数据字段
    width: 50, // 可以自定义宽度
    scopedSlots: { customRender: 'bodyCell' }, // 对应模板中的具名插槽
  },
  {
    title: '填报周期',
    dataIndex: 'year',
    width: 200,
  },
  {
    title: '公司名称',
    dataIndex: 'companyName',
    width: 180,
  },
  {
    title: '项目名称',
    dataIndex: 'projectName',
    width: 180,
  },
  {
    title: '建设地点',
    dataIndex: 'constructionSite',
    width: 180,
  },
  {
    title: '立项总投资(万元)',
    dataIndex: 'totalInvestment',
    width: 180,
  },
  {
    title: '年资金计划额合计(万元)',
    dataIndex: 'plannedQuotaTotal',
    width: 180,
  },
  {
    title: '专项拨款合计(万元)',
    dataIndex: 'specialFundTotal',
    width: 180,
  },
  {
    title: '银行融资合计(万元)',
    dataIndex: 'bankFinancingTotal',
    width: 180,
  },
  {
    title: '自有资金合计(万元)',
    dataIndex: 'ownFundsTotal',
    width: 180,
  },
  {
    title: '当年资金缺口(万元)',
    dataIndex: 'fundingGap',
    width: 180,
  },
  {
    title: '建设性质',
    dataIndex: 'attribute',
    width: 180,
  },
  {
    title: '开竣工时间',
    dataIndex: 'beginTime',
    width: 180,
  },
  {
    title: '当年底预计形象进度',
    dataIndex: 'schedule',
    width: 180,
  },
  {
    title: '项目主管部门',
    dataIndex: 'competentDepartment',
    width: 180,
  },
  {
    title: '备注',
    dataIndex: 'remark',
    width: 180,
  },
];
// 4-月度资金计划列表
export const monthlyPlanColumns: BasicColumn[] = [
  {
    title: '',
    dataIndex: '',
    children: [
      {
        title: '序号',
        dataIndex: 'serialNumber', // 这个dataIndex仅作为标识，不对应实际数据字段
        width: 50, // 可以自定义宽度
        scopedSlots: { customRender: 'bodyCell' }, // 对应模板中的具名插槽
      },
      {
        title: '填报年份',
        dataIndex: 'monthYear',
        width: 200,
      },
      {
        title: '公司名称',
        dataIndex: 'companyName',
        width: 180,
      },
      {
        title: '项目名称',
        dataIndex: 'projectName',
        width: 180,
      },
      {
        title: '收款单位',
        dataIndex: 'collectingUnit',
        width: 180,
      },
      {
        title: '合同额(万元)',
        dataIndex: 'contractAmount',
        width: 180,
      },
    ],
  },
  {
    title: '产值完成情况',
    dataIndex: '',
    children: [
      {
        title: '上月实际完成值(万元)',
        dataIndex: 'completionValueActual',
        width: 180,
      },
      {
        title: '累计完成值(万元)',
        dataIndex: 'accumulateCompletionValue',
        width: 180,
      },
      {
        title: '本月计划完成值(万元)',
        dataIndex: 'planCompletionValue',
        width: 180,
      },
      {
        title: '上月计划数(万元)',
        dataIndex: 'lastMonthPlan',
        width: 180,
      },
    ],
  },
  {
    title: '资金支付情况',
    dataIndex: '',
    children: [
      {
        title: '上月实付数(万元)',
        dataIndex: 'lastMonthActual',
        width: 180,
      },
      {
        title: '累计支付数(万元)',
        dataIndex: 'accumulatePayment',
        width: 180,
      },
      {
        title: '本月计划数(万元)',
        dataIndex: 'thisPlanNumber',
        width: 180,
      },
    ],
  },
  {
    title: '资金来源',
    dataIndex: '',
    children: [
      {
        title: '专项债拨款(万元)',
        dataIndex: 'specialFund',
        width: 180,
      },
      {
        title: '政府拨款(万元)',
        dataIndex: 'governmentFund',
        width: 180,
      },
      {
        title: '银行融资(万元)',
        dataIndex: 'banFinancing',
        width: 180,
      },
      {
        title: '自有资金(万元)',
        dataIndex: 'ownFund',
        width: 180,
      },
    ],
  },
  {
    title: '',
    dataIndex: '',
    children: [
      {
        title: '资金缺口(万元)',
        dataIndex: 'fundGap',
        width: 180,
      },
      {
        title: '支付等级',
        dataIndex: 'paymentLevel',
        width: 180,
      },
      {
        title: '备注',
        dataIndex: 'remark',
        width: 180,
      },
    ],
  },
];
// 5-已竣工列表
export const completedColumns: BasicColumn[] = [
  {
    title: '序号',
    dataIndex: 'serialNumber', // 这个dataIndex仅作为标识，不对应实际数据字段
    width: 50, // 可以自定义宽度
    scopedSlots: { customRender: 'bodyCell' }, // 对应模板中的具名插槽
  },
  {
    title: '填报周期',
    dataIndex: 'filingCycle',
    width: 200,
  },
  {
    title: '公司名称',
    dataIndex: 'company',
    width: 180,
  },
  {
    title: '项目名称',
    dataIndex: 'projectName',
    width: 180,
  },
  {
    title: '建设地点',
    dataIndex: 'constructionSite',
    width: 180,
  },
  {
    title: '立项总投资合计(万元)',
    dataIndex: 'projectApproval',
    width: 180,
  },
  {
    title: '上一年底前累计实付额(万元)',
    dataIndex: 'totalActualPay',
    width: 180,
  },
  {
    title: '年资金计划额合计(万元)',
    dataIndex: 'totalValue',
    width: 180,
  },
  {
    title: '专项拨款合计(万元)',
    dataIndex: 'totalSpecialBond',
    width: 180,
  },
  {
    title: '银行融资合计(万元)',
    dataIndex: 'totalBankFinancing',
    width: 180,
  },
  {
    title: '自有资金合计(万元)',
    dataIndex: 'totalOwnFunds',
    width: 180,
  },
  {
    title: '当年资金缺口(万元)',
    dataIndex: 'fundingGap',
    width: 180,
  },
  {
    title: '项目主管部门',
    dataIndex: 'competentDepartment',
    width: 180,
  },
  {
    title: '备注',
    dataIndex: 'remarks',
    width: 180,
  },
];
// 6-招标计划列表
export const biddingPlanColumns = [
  {
    title: '序号',
    dataIndex: 'serialNumber',
    width: 100,
  },
  {
    title: '填报年份',
    dataIndex: 'tenderYear',
    width: 200,
  },
  {
    title: '项目名称',
    sort: true,
    dataIndex: 'projectName',
    width: 180,
  },
  {
    title: '立项主体',
    sort: true,
    dataIndex: 'projectInitiator',
    width: 180,
  },
  {
    title: '资金来源',
    sort: true,
    dataIndex: 'fundingSource',
    width: 180,
  },
  {
    title: '立项投资额(万元)',
    sort: true,
    dataIndex: 'investmentAmount',
    width: 180,
  },
  {
    title: '招标类型',
    dataIndex: 'biddingType',
    width: 180,
  },
  {
    title: '招标内容',
    sort: true,
    dataIndex: 'tenderContent',
    width: 180,
  },
  {
    title: '预计控制价(万元)',
    dataIndex: 'controlPrice',
    width: 180,
  },
  {
    title: '计划工期',
    dataIndex: 'plannedPeriod',
    width: 180,
  },
  {
    title: '招标方式',
    dataIndex: 'biddingMethod',
    width: 180,
  },
  {
    title: '计划招标周期',
    dataIndex: 'biddingPeriod',
    width: 180,
  },
  {
    title: '备注',
    dataIndex: 'remark',
    width: 180,
  },
];
// 7-招标管理列表
export const biddingManagementColumns = [
  {
    title: '序号',
    dataIndex: 'serialNumber',
    width: 100,
  },
  {
    title: '填报年份',
    dataIndex: 'tenderYear',
    width: 200,
  },
  {
    title: '项目名称 ',
    sort: true,
    dataIndex: 'projectName',
    width: 180,
  },
  {
    title: '立项投资额(万元)',
    dataIndex: 'investmentAmount',
    width: 180,
  },
  {
    title: '资金来源',
    dataIndex: 'fundingSource',
    width: 180,
  },
  {
    title: '招标类型',
    dataIndex: 'biddingType',
    width: 180,
  },
  {
    title: '招标内容',
    dataIndex: 'tenderContent',
    width: 180,
  },
  {
    title: '招标控制(万元)',
    dataIndex: 'controlPrice',
    width: 180,
  },
  {
    title: '建设模式',
    dataIndex: 'constructionMode',
    width: 180,
  },
  {
    title: '招标采购方式',
    dataIndex: 'procurementMethod',
    width: 180,
  },
  {
    title: '招标完成情况',
    dataIndex: 'completionStatus',
    width: 180,
  },
  {
    title: '开标时间',
    dataIndex: 'openingTime',
    width: 180,
  },
  {
    title: '中标单位',
    dataIndex: 'winningBidder',
    width: 180,
  },
  {
    title: '中标金额(万元)',
    dataIndex: 'winningAmount',
    width: 150,
  },
  {
    title: '中标工期',
    dataIndex: 'winningPeriod',
    width: 150,
  },
  {
    title: '合同签订日期',
    dataIndex: 'signingDate',
    width: 180,
  },
  {
    title: '会议纪要',
    dataIndex: 'meetingMinute',
    width: 180,
  },
  {
    title: '招标信息发布渠道',
    dataIndex: 'releaseChannels',
    width: 180,
  },
  {
    title: '招标公告发布网址\n' + '\n' + '（仅限公开招标项目）',
    dataIndex: 'publishWebsite',
    width: 180,
  },
  {
    title: '中标结果公示网址\n' + '\n' + '（仅限公开招标项目）',
    dataIndex: 'publicityWebsite',
    width: 180,
  },
  {
    title: '是否存在投诉举报情况',
    dataIndex: 'isReportingSituation',
    width: 180,
  },
  {
    title: '投诉举报解决处理情况',
    dataIndex: 'handSituation',
    width: 180,
  },
  {
    title: '备注',
    dataIndex: 'remark',
    width: 180,
  },
];
// 8-结算管理列表
export const settlementManagementColumns = [
  {
    title: '序号',
    dataIndex: 'serialNumber',
    width: 100,
  },
  {
    title: '填报周期',
    dataIndex: 'yearQuarter',
    width: 140,
  },
  {
    title: '立项投资额(万元)',
    dataIndex: 'projectInvestment',
    width: 140,
  },
  {
    title: '资金来源',
    dataIndex: 'fundingSource',
    width: 140,
  },
  {
    title: '招标方式',
    dataIndex: 'biddingMethod',
    width: 140,
  },
  {
    title: '合同类型',
    dataIndex: 'contracYpe',
    width: 140,
  },
  {
    title: '合同名称',
    dataIndex: 'contractName',
    width: 140,
  },
  {
    title: '甲方单位名称',
    dataIndex: 'firstPartyName',
    width: 180,
  },
  {
    title: '乙方单位名称',
    dataIndex: 'secondPartyName',
    width: 140,
  },
  {
    title: '合同形式',
    dataIndex: 'formOfContract',
    width: 140,
  },
  {
    title: '合同签订时间',
    dataIndex: 'contractSigningTime',
    width: 140,
  },
  {
    title: '竣工时间',
    dataIndex: 'closingTime',
    width: 140,
  },
  {
    title: '结算完成时间',
    dataIndex: 'closingTimeDatetime',
    width: 140,
  },
  {
    title: '合同金额(万元)',
    dataIndex: 'contractAmount',
    width: 140,
  },
  {
    title: '签证、变更金额(万元)',
    dataIndex: 'submittedForSettlement',
    width: 140,
  },
  {
    title: '结算报送金额(万元)',
    dataIndex: 'superContractScale',
    width: 140,
  },
  {
    title: '结算审定金额(万元)',
    dataIndex: 'sumOfMoney',
    width: 140,
  },
  {
    title: '结算审核金额超合同额比例',
    dataIndex: 'proportionContractAmount',
    width: 140,
  },
  {
    title: '会议纪要',
    dataIndex: 'meetingMinutes',
    width: 140,
  },
  {
    title: '备注',
    dataIndex: 'remark',
    width: 140,
  },
];
// 9-变更签证管理列表
export const changeSignatureColumns = [
  {
    title: '填报周期',
    dataIndex: 'yearQuarter',
    width: 200,
  },
  {
    title: '项合同名称',
    dataIndex: 'contractName',
    width: 180,
  },
  {
    title: '合同金额',
    dataIndex: 'contractAmount',
    width: 180,
  },
  {
    title: '合同累计签证、变更金额（含本次）(万元)',
    dataIndex: 'changeAmount',
    width: 180,
  },
  {
    title: '累计变更签证金额占合同金额比例',
    dataIndex: 'amountRatio',
    width: 180,
  },
  {
    title: '变更编号',
    dataIndex: 'changeNumber',
    width: 180,
  },
  {
    title: '变更类型',
    dataIndex: 'changeType',
    width: 180,
  },
  {
    title: '责任方',
    dataIndex: 'responsibleParty',
    width: 180,
  },
  {
    title: '变更内容',
    dataIndex: 'changeContent',
    width: 180,
  },
  {
    title: '预估变更金额(万元)',
    dataIndex: 'visaAmount',
    width: 180,
  },
  {
    title: '预估变更金额占合同金额比例',
    dataIndex: 'contractValueRatio',
    width: 180,
  },
  {
    title: '签证编号',
    dataIndex: 'visaNumber',
    width: 180,
  },
];
// 10-安全隐患管理列表
export const potentialSafetyColumns = [
  {
    title: '填报周期',
    dataIndex: 'fillingPeriod',
    width: 150,
  },
  {
    title: '隐患描述',
    dataIndex: 'describe',
    width: 150,
  },
  {
    title: '隐患级别',
    dataIndex: 'level',
    width: 150,
  },
  {
    title: '计划费用(万元)',
    dataIndex: 'planCost',
    width: 180,
  },
  {
    title: '实际费用(万元)',
    dataIndex: 'actualCost',
    width: 180,
  },
  {
    title: '计划时间',
    dataIndex: 'planTime',
    width: 180,
  },
  {
    title: '实际时间',
    dataIndex: 'actualTime',
    width: 180,
  },
  {
    title: '隐患治理后的评估情况',
    dataIndex: 'assessmentSituation',
    width: 180,
  },
  {
    title: '责任人',
    dataIndex: 'responsiblePerson',
    width: 180,
  },
];
// 11-安全教育培训列表
export const safetyEducationColumns = [
  {
    title: '序号',
    dataIndex: 'serialNumber',
    width: 100,
  },
  {
    title: '填报周期',
    dataIndex: 'fillingPeriod',
    width: 150,
  },
  {
    title: '培训时间',
    dataIndex: 'trainingTime',
    width: 150,
  },
  {
    title: '培训主题',
    dataIndex: 'trainingTheme',
    width: 150,
  },
  {
    title: '培训类型',
    dataIndex: 'trainingType',
    width: 180,
  },
  {
    title: '培训形式',
    dataIndex: 'trainingFormat',
    width: 180,
  },
  {
    title: '计划会议',
    dataIndex: 'trainingMeet',
    width: 180,
  },
  {
    title: '培训人员',
    dataIndex: 'trainers',
    width: 180,
  },
  {
    title: '学识(合计)',
    dataIndex: 'knowledge',
    width: 180,
  },
  {
    title: '人数',
    dataIndex: 'numberOfPeople',
    width: 180,
  },
  {
    title: '备注',
    dataIndex: 'remark',
    width: 180,
  },
];

export const contractColumns = [
  {
    title: '合同名称',
    dataIndex: 'contrcatName',
    width: 180,
  },
  {
    title: '项目名称',
    dataIndex: 'projectName',
    width: 180,
  },
  {
    title: '结算金额(万元)',
    dataIndex: 'investmentAmount',
    width: 180,
  },
  {
    title: '累计支付数',
    dataIndex: 'accumulatePayment',
    width: 180,
  },
  {
    title: '收款单位',
    dataIndex: 'collectingUnit',
    width: 200,
  },
  {
    title: '合同额(万元)',
    dataIndex: 'contractAmount',
    width: 180,
  },
];

export const annexColumns = [
  {
    title: '文件名',
    dataIndex: 'fileName',
    width: 180,
  },
  {
    title: '大小',
    dataIndex: 'fileSize',
    width: 180,
  },
  {
    title: '上传时间',
    dataIndex: 'createTime',
    width: 180,
  },
  {
    title: '上传人员',
    dataIndex: 'createBy',
    width: 180,
  },
  {
    title: '备注内容',
    dataIndex: 'remark',
    width: 180,
  },
];

// 1-项目库-投资计划导出
export const columnsExport: BasicColumn[] = [
  {
    title: '填报周期',
    dataIndex: 'filingCycle',
    width: 180,
  },
  {
    title: '项目名称',
    dataIndex: 'projectName',
    width: 180,
  },
  {
    title: '建设地点',
    dataIndex: 'constructionSite',
    width: 180,
  },
  {
    title: '项目概况',
    dataIndex: 'projectOverview',
    width: 180,
  },
  {
    title: '建设规模',
    dataIndex: 'constructionScale',
    width: 180,
  },
  {
    title: '建设目的及项目功能',
    dataIndex: 'constructionPurpose',
    width: 180,
  },
  {
    title: '建设模式',
    dataIndex: 'constructionMode',
    width: 180,
  },
  {
    title: '资金来源',
    dataIndex: 'fundingSource',
    width: 180,
  },
  {
    title: '项目类型',
    dataIndex: 'projectType',
    width: 180,
  },
  {
    title: '总投资',
    dataIndex: 'totalInvestment',
    width: 180,
  },
  {
    title: '三年滚动投资计划',
    dataIndex: 'totalAmount',
    width: 180,
  },
  {
    title: '该年财政预算匹配资金',
    dataIndex: 'matchingFunds',
    width: 180,
  },
  {
    title: '其中专项债项目该年预计使用专项债资金',
    dataIndex: 'specialBondFunds',
    width: 180,
  },
  {
    title: '该年计划资金',
    dataIndex: 'planFunds',
    width: 180,
  },

  {
    title: '建设性质',
    dataIndex: 'attribute',
    width: 180,
  },
  {
    title: '开工时间',
    dataIndex: 'beginTime',
    width: 180,
  },
  {
    title: '竣工时间',
    dataIndex: 'endTime',
    width: 180,
  },

  {
    title: '该年底预计形象进度',
    dataIndex: 'schedule',
    width: 180,
  },

  {
    title: '实施主体',
    dataIndex: 'implementingEntity',
    width: 180,
  },

  {
    title: '项目主管部门',
    dataIndex: 'competentDepartment',
    width: 180,
  },
  {
    title: '备注',
    dataIndex: 'remarks',
    width: 180,
  },
];
// 2-项目库-计划完成情况导出
export const performanceExportColumns: BasicColumn[] = [
  {
    title: '填报年份',
    dataIndex: 'filingCycle',
    width: 200,
  },
  {
    title: '项目名称',
    dataIndex: 'projectName',
    width: 200,
  },
  {
    title: '建设地点',
    dataIndex: 'constructionSite',
    width: 180,
  },
  {
    title: '项目概况',
    dataIndex: 'projectOverview',
    width: 180,
  },
  {
    title: '建设规模',
    dataIndex: 'constructionScale',
    width: 180,
  },
  {
    title: '建设目的及项目功能',
    dataIndex: 'constructionPurpose',
    width: 180,
  },
  {
    title: '建设模式',
    dataIndex: 'constructionMode',
    width: 180,
  },
  {
    title: '资金来源',
    dataIndex: 'fundingSource',
    width: 180,
  },
  {
    title: '项目类型',
    dataIndex: 'projectType',
    width: 180,
  },
  {
    title: '总投资',
    dataIndex: 'totalInvestment',
    width: 180,
  },
  {
    title: '该年之前总投资额（不含该年）',
    dataIndex: 'totalBefore',
    width: 180,
  },
  {
    title: '该年计划投资额',
    dataIndex: 'planNum',
    width: 180,
  },
  {
    title: '该年计划资金',
    dataIndex: 'planFunds',
    width: 180,
  },
  {
    title: '该年实付资金',
    dataIndex: 'actualPay',
    width: 180,
  },
  {
    title: '建设性质',
    dataIndex: 'attribute',
    width: 180,
  },
  {
    title: '开工时间',
    dataIndex: 'beginTime',
    width: 180,
  },
  {
    title: '竣工时间',
    dataIndex: 'endTime',
    width: 180,
  },
  {
    title: '该年底形象进度',
    dataIndex: 'completionSchedule',
    width: 180,
  },
  {
    title: '实施主体',
    dataIndex: 'implementingEntity',
    width: 180,
  },
  {
    title: '项目主管部门',
    dataIndex: 'competentDepartment',
    width: 180,
  },
  {
    title: '备注',
    dataIndex: 'completionRemarks',
    width: 180,
  },
];
// 3-项目库-年度资金计划导出
export const annualPlanExportColumns: BasicColumn[] = [
  {
    title: '填报周期',
    dataIndex: 'year',
    width: 200,
  },
  {
    title: '公司名称',
    dataIndex: 'companyName',
    width: 180,
  },
  {
    title: '项目名称',
    dataIndex: 'projectName',
    width: 180,
  },
  {
    title: '建设地点',
    dataIndex: 'constructionSite',
    width: 180,
  },
  {
    title: '立项总投资',
    dataIndex: 'totalInvestment',
    width: 180,
  },
  {
    title: '年资金计划额合计',
    dataIndex: 'plannedQuotaTotal',
    width: 180,
  },
  {
    title: '专项拨款合计',
    dataIndex: 'specialFundTotal',
    width: 180,
  },
  {
    title: '银行融资合计',
    dataIndex: 'bankFinancingTotal',
    width: 180,
  },
  {
    title: '自有资金合计',
    dataIndex: 'ownFundsTotal',
    width: 180,
  },
  {
    title: '当年资金缺口',
    dataIndex: 'fundingGap',
    width: 180,
  },
  {
    title: '建设性质',
    dataIndex: 'attribute',
    width: 180,
  },
  {
    title: '开工时间',
    dataIndex: 'beginTime',
    width: 180,
  },
  {
    title: '竣工时间',
    dataIndex: 'endTime',
    width: 180,
  },
  {
    title: '当年底预计形象进度',
    dataIndex: 'schedule',
    width: 180,
  },
  {
    title: '项目主管部门',
    dataIndex: 'competentDepartment',
    width: 180,
  },
  {
    title: '备注',
    dataIndex: 'remark',
    width: 180,
  },
];
// 4-项目库-月季度导出
export const monthExportColumns: BasicColumn[] = [
  {
    title: '填报年份',
    dataIndex: 'monthYear',
    width: 200,
  },
  {
    title: '公司名称',
    dataIndex: 'companyName',
    width: 200,
  },
  {
    title: '项目名称',
    dataIndex: 'projectName',
    width: 180,
  },
  {
    title: '合同名称',
    dataIndex: 'contrcatName',
    width: 180,
  },
  {
    title: '收款单位',
    dataIndex: 'collectingUnit',
    width: 180,
  },
  {
    title: '合同额',
    dataIndex: 'contractAmount',
    width: 180,
  },
  {
    title: '上月实际完成值',
    dataIndex: 'completionValueActual',
    width: 180,
  },
  {
    title: '累计完成值',
    dataIndex: 'accumulateCompletionValue',
    width: 180,
  },
  {
    title: '本月计划完成值',
    dataIndex: 'planCompletionValue',
    width: 180,
  },
  {
    title: '上月计划数',
    dataIndex: 'lastMonthPlan',
    width: 180,
  },
  {
    title: '上月实付数',
    dataIndex: 'lastMonthActual',
    width: 180,
  },
  {
    title: '累计支付数',
    dataIndex: 'accumulatePayment',
    width: 180,
  },
  {
    title: '本月计划数',
    dataIndex: 'thisPlanNumber',
    width: 180,
  },
  {
    title: '专项拨款',
    dataIndex: 'specialFund',
    width: 180,
  },
  {
    title: '政府拨款',
    dataIndex: 'governmentFund',
    width: 180,
  },
  {
    title: '银行拨款',
    dataIndex: 'banFinancing',
    width: 180,
  },
  {
    title: '自有资金',
    dataIndex: 'ownFund',
    width: 180,
  },
  {
    title: '资金缺口',
    dataIndex: 'fundGap',
    width: 180,
  },
  {
    title: '支付等级',
    dataIndex: 'paymentLevel',
    width: 180,
  },
  {
    title: '备注',
    dataIndex: 'remark',
    width: 180,
  },
];
// 5-项目库-已竣工导出
export const completedExportColumns: BasicColumn[] = [
  {
    title: '填报周期',
    dataIndex: 'filingCycle',
    width: 200,
  },
  {
    title: '公司名称',
    dataIndex: 'company',
    width: 180,
  },
  {
    title: '项目名称',
    dataIndex: 'projectName',
    width: 180,
  },
  {
    title: '建设地点',
    dataIndex: 'constructionSite',
    width: 180,
  },
  {
    title: '立项总投资合计',
    dataIndex: 'projectApproval',
    width: 180,
  },
  {
    title: '上一年底前累计实付额',
    dataIndex: 'totalActualPay',
    width: 180,
  },
  {
    title: '年资金计划额合计',
    dataIndex: 'totalValue',
    width: 180,
  },
  {
    title: '专项拨款合计',
    dataIndex: 'totalSpecialBond',
    width: 180,
  },
  {
    title: '银行融资合计',
    dataIndex: 'totalBankFinancing',
    width: 180,
  },
  {
    title: '自有资金合计',
    dataIndex: 'totalOwnFunds',
    width: 180,
  },
  {
    title: '当年资金缺口',
    dataIndex: 'fundingGap',
    width: 180,
  },
  {
    title: '项目主管部门',
    dataIndex: 'competentDepartment',
    width: 180,
  },
  {
    title: '备注',
    dataIndex: 'remarks',
    width: 180,
  },
];
// 6-项目库-招标计划导出
export const exportBiddingPlanColumns = [
  {
    title: '填报年份',
    dataIndex: 'fillingPeriod',
    width: 200,
  },
  {
    title: '项目名称',
    sort: true,
    dataIndex: 'projectName',
    width: 180,
  },
  {
    title: '立项主体',
    sort: true,
    dataIndex: 'projectInitiator',
    width: 180,
  },
  {
    title: '资金来源',
    sort: true,
    dataIndex: 'fundingSource',
    width: 180,
  },
  {
    title: '立项投资额（万元) ',
    sort: true,
    dataIndex: 'investmentAmount',
    width: 180,
  },
  {
    title: '招标类型',
    dataIndex: 'biddingType',
    width: 180,
  },
  {
    title: '招标内容',
    sort: true,
    dataIndex: 'tenderContent',
    width: 180,
  },
  {
    title: '预计控制价（万元）',
    dataIndex: 'controlPrice',
    width: 180,
  },
  {
    title: '计划工期',
    dataIndex: 'plannedPeriod',
    width: 180,
  },
  {
    title: '招标方式',
    dataIndex: 'biddingMethod',
    width: 180,
  },
  {
    title: '计划招标周期',
    dataIndex: 'biddingPeriod',
    width: 180,
  },
  {
    title: '备注',
    dataIndex: 'remark',
    width: 180,
  },
];
// 7-项目库-招标管理导出
export const exportBiddingManagementColumns = [
  {
    title: '填报年份',
    dataIndex: 'fillingPeriod',
    width: 200,
  },
  {
    title: '项目名称',
    sort: true,
    dataIndex: 'projectName',
    width: 180,
  },
  {
    title: '立项投资额（万元)',
    dataIndex: 'investmentAmount',
    width: 180,
  },
  {
    title: '资金来源',
    dataIndex: 'fundingSource',
    width: 180,
  },
  {
    title: '招标类型',
    dataIndex: 'biddingType',
    width: 180,
  },
  {
    title: '招标内容',
    dataIndex: 'tenderContent',
    width: 180,
  },
  {
    title: '招标控制（元）',
    dataIndex: 'controlPrice',
    width: 180,
  },
  {
    title: '建设模式',
    dataIndex: 'constructionMode',
    width: 180,
  },
  {
    title: '招标采购方式',
    dataIndex: 'procurementMethod',
    width: 180,
  },
  {
    title: '招标完成情况',
    dataIndex: 'completionStatus',
    width: 180,
  },
  {
    title: '开标时间',
    dataIndex: 'openingTime',
    width: 180,
  },
  {
    title: '中标单位',
    dataIndex: 'winningBidder',
    width: 180,
  },
  {
    title: '中标金额（元）',
    dataIndex: 'winningAmount',
    width: 150,
  },
  {
    title: '中标工期',
    dataIndex: 'winningPeriod',
    width: 150,
  },
  {
    title: '合同签订日期',
    dataIndex: 'signingDate',
    width: 180,
  },
  {
    title: '会议纪要',
    dataIndex: 'meetingMinute',
    width: 150,
  },
  {
    title: '招标信息发布渠道',
    dataIndex: 'releaseChannels',
    width: 180,
  },
  {
    title: '招标公告发布网址（仅限公开招标项目）',
    dataIndex: 'publishWebsite',
    width: 180,
  },
  {
    title: '中标结果公示网址（仅限公开招标项目）',
    dataIndex: 'publicityWebsite',
    width: 180,
  },
  {
    title: '是否存在投诉举报情况',
    dataIndex: 'isReportingSituation',
    width: 180,
  },
  {
    title: '投诉举报解决处理情况',
    dataIndex: 'handSituation',
    width: 180,
  },
  {
    title: '备注',
    dataIndex: 'remark',
    width: 180,
  },
];
// 8-项目库-结算管理列表
export const settlementManagementExportColumns = [
  {
    title: '填报周期',
    dataIndex: 'yearQuarter',
    width: 140,
  },
  {
    title: '立项投资额（万元）',
    dataIndex: 'projectInvestment',
    width: 140,
  },
  {
    title: '资金来源',
    dataIndex: 'fundingSource',
    width: 140,
  },
  {
    title: '招标方式',
    dataIndex: 'biddingMethod',
    width: 140,
  },
  {
    title: '合同类型',
    dataIndex: 'contracYpe',
    width: 140,
  },
  {
    title: '合同名称',
    dataIndex: 'contractName',
    width: 140,
  },
  {
    title: '甲方单位名称',
    dataIndex: 'firstPartyName',
    width: 180,
  },
  {
    title: '乙方单位名称',
    dataIndex: 'secondPartyName',
    width: 140,
  },
  {
    title: '合同形式',
    dataIndex: 'formOfContract',
    width: 140,
  },
  {
    title: '合同签订时间',
    dataIndex: 'contractSigningTime',
    width: 140,
  },
  {
    title: '竣工时间',
    dataIndex: 'closingTime',
    width: 140,
  },
  {
    title: '结算完成时间',
    dataIndex: 'closingTimeDatetime',
    width: 140,
  },
  {
    title: '合同金额（元）',
    dataIndex: 'contractAmount',
    width: 140,
  },
  {
    title: '签证、变更金额（元）',
    dataIndex: 'submittedForSettlement',
    width: 140,
  },
  {
    title: '结算报送金额（元)',
    dataIndex: 'superContractScale',
    width: 140,
  },
  {
    title: '结算审定金额（元）',
    dataIndex: 'sumOfMoney',
    width: 140,
  },
  {
    title: '结算审核金额超合同额比例',
    dataIndex: 'proportionContractAmount',
    width: 140,
  },
  {
    title: '会议纪要',
    dataIndex: 'meetingMinutes',
    width: 140,
  },
  {
    title: '备注',
    dataIndex: 'remark',
    width: 140,
  },
];
// 9-项目库-变更签证管理列表
export const changeSignatureExportColumns = [
  {
    title: '填报周期',
    dataIndex: 'yearQuarter',
    width: 200,
  },
  {
    title: '项合同名称',
    dataIndex: 'contractName',
    width: 180,
  },
  {
    title: '合同金额',
    dataIndex: 'contractAmount',
    width: 180,
  },
  {
    title: '合同累计签证、变更金额（含本次）（元）',
    dataIndex: 'changeAmount',
    width: 180,
  },
  {
    title: '累计变更签证金额占合同金额比例',
    dataIndex: 'amountRatio',
    width: 180,
  },
  {
    title: '变更编号',
    dataIndex: 'changeNumber',
    width: 180,
  },
  {
    title: '变更类型',
    dataIndex: 'changeType',
    width: 180,
  },
  {
    title: '责任方',
    dataIndex: 'responsibleParty',
    width: 180,
  },
  {
    title: '变更内容',
    dataIndex: 'changeContent',
    width: 180,
  },
  {
    title: '预估变更金额（元)',
    dataIndex: 'visaAmount',
    width: 180,
  },
  {
    title: '预估变更金额占合同金额比例',
    dataIndex: 'contractValueRatio',
    width: 180,
  },
  {
    title: '签证编号',
    dataIndex: 'visaNumber',
    width: 180,
  },
];
// 10-项目库-安全隐患管理列表
export const potentialSafetyExportColumns = [
  {
    title: '填报周期',
    dataIndex: 'fillingPeriod',
    width: 150,
  },
  {
    title: '隐患描述',
    dataIndex: 'describe',
    width: 150,
  },
  {
    title: '隐患级别',
    dataIndex: 'level',
    width: 150,
  },
  {
    title: '计划费用(万元)',
    dataIndex: 'planCost',
    width: 180,
  },
  {
    title: '实际费用(万元)',
    dataIndex: 'actualCost',
    width: 180,
  },
  {
    title: '计划时间',
    dataIndex: 'planTime',
    width: 180,
  },
  {
    title: '实际时间',
    dataIndex: 'actualTime',
    width: 180,
  },
  {
    title: '隐患治理后的评估情况',
    dataIndex: 'assessmentSituation',
    width: 180,
  },
  {
    title: '责任人',
    dataIndex: 'responsiblePerson',
    width: 180,
  },
];
// 11-项目库-安全教育培训列表
export const safetyEducationExportColumns = [
  {
    title: '填报周期',
    dataIndex: 'fillingPeriod',
    width: 150,
  },
  {
    title: '培训时间',
    dataIndex: 'trainingTime',
    width: 150,
  },
  {
    title: '培训主题',
    dataIndex: 'trainingTheme',
    width: 150,
  },
  {
    title: '培训类型',
    dataIndex: 'trainingType',
    width: 180,
  },
  {
    title: '培训形式',
    dataIndex: 'trainingFormat',
    width: 180,
  },
  {
    title: '计划会议',
    dataIndex: 'trainingMeet',
    width: 180,
  },
  {
    title: '培训人员',
    dataIndex: 'trainers',
    width: 180,
  },
  {
    title: '学识(合计)',
    dataIndex: 'knowledge',
    width: 180,
  },
  {
    title: '人数',
    dataIndex: 'numberOfPeople',
    width: 180,
  },
  {
    title: '备注',
    dataIndex: 'remark',
    width: 180,
  },
];
